package com.usky.fire.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.usky.common.core.bean.CommonPage;
import com.usky.common.core.util.StringUtils;
import com.usky.common.security.utils.SecurityUtils;
import com.usky.fire.domain.PatrolInspectionAttendance;
import com.usky.fire.mapper.PatrolInspectionAttendanceMapper;
import com.usky.fire.service.PatrolInspectionAttendanceService;
import com.usky.common.mybatis.core.AbstractCrudService;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;


/**
 * <p>
 * 签到、签退信息记录表 服务实现类
 * </p>
 *
 * @author fu
 * @since 2024-02-05
 */
@Service
public class PatrolInspectionAttendanceServiceImpl extends AbstractCrudService<PatrolInspectionAttendanceMapper, PatrolInspectionAttendance> implements PatrolInspectionAttendanceService {
    @Override
    public CommonPage<PatrolInspectionAttendance> pageList(String requestBody) {
        JSONObject request = JSONObject.parseObject(requestBody);
        Integer pageNum = (Integer) request.getOrDefault("pageNum",1);
        Integer pageSize = (Integer) request.getOrDefault("pageSize",10);
        Integer typeId = (Integer) request.get("typeId");
        String operator = (String) request.get("operator");
        String startTimeStr = request.getString("startTime");
        LocalDateTime startTime = StringUtils.isNotBlank(startTimeStr) ? LocalDateTime.parse(startTimeStr, DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss")) : null;
        String endTimeStr = request.getString("endTime");
        LocalDateTime endTime = StringUtils.isNotBlank(endTimeStr) ? LocalDateTime.parse(endTimeStr, DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss")) : LocalDateTime.now();
        //LocalDateTime startTime = (LocalDateTime) requestVO.getOrDefault("startTime",null);
        //LocalDateTime endTime = (LocalDateTime) requestVO.getOrDefault("endTime",LocalDateTime.now());
        IPage<PatrolInspectionAttendance> page = new Page<>(pageNum,pageSize);
        LambdaQueryWrapper<PatrolInspectionAttendance> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(PatrolInspectionAttendance::getTenantId,SecurityUtils.getTenantId());

        if (typeId!=null){
            queryWrapper.eq(PatrolInspectionAttendance::getTypeId,typeId);
        }

        if (StringUtils.isNotBlank(operator)) {
            queryWrapper.eq(PatrolInspectionAttendance::getOperator, operator);
        }

        if (startTime != null && endTime != null) {
            queryWrapper.between(PatrolInspectionAttendance::getOperateDate, startTime, endTime);
        } else if(startTime == null && endTime !=null){
            queryWrapper.le(PatrolInspectionAttendance::getOperateDate, endTime);
        }

        queryWrapper.orderByDesc(PatrolInspectionAttendance::getId);
        page = this.page(page,queryWrapper);
        return new CommonPage<>(page.getRecords(),page.getTotal(),pageNum,pageSize);
    }


    @Override
    public void add(PatrolInspectionAttendance patrolInspectionAttendance) {
        baseMapper.insert(patrolInspectionAttendance);
    }


}
